/*
 * Copyright 2019 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.android.overtheair.spi.v1;

import com.google.android.overtheair.v1.Chart;
import com.google.android.overtheair.v1.Config;
import com.google.android.overtheair.v1.CreateConfigRequest;
import com.google.android.overtheair.v1.CreateGroupMemberRequest;
import com.google.android.overtheair.v1.CreateGroupMembersRequest;
import com.google.android.overtheair.v1.CreateGroupMembersResponse;
import com.google.android.overtheair.v1.CreateGroupRequest;
import com.google.android.overtheair.v1.DeleteConfigRequest;
import com.google.android.overtheair.v1.DeleteConfigResponse;
import com.google.android.overtheair.v1.DeleteGroupMemberRequest;
import com.google.android.overtheair.v1.DeleteGroupMemberResponse;
import com.google.android.overtheair.v1.DeleteGroupMembersRequest;
import com.google.android.overtheair.v1.DeleteGroupMembersResponse;
import com.google.android.overtheair.v1.DeleteGroupRequest;
import com.google.android.overtheair.v1.DeleteGroupResponse;
import com.google.android.overtheair.v1.DeletePackageRequest;
import com.google.android.overtheair.v1.DeletePackageResponse;
import com.google.android.overtheair.v1.Deployment;
import com.google.android.overtheair.v1.DisableAllEnabledGroupsOfConfigRequest;
import com.google.android.overtheair.v1.DisableAllEnabledGroupsOfConfigResponse;
import com.google.android.overtheair.v1.DisableGroupsRequest;
import com.google.android.overtheair.v1.DisableGroupsResponse;
import com.google.android.overtheair.v1.EnableGroupsRequest;
import com.google.android.overtheair.v1.EnableGroupsResponse;
import com.google.android.overtheair.v1.GetConfigRequest;
import com.google.android.overtheair.v1.GetDeploymentRequest;
import com.google.android.overtheair.v1.GetGroupChartRequest;
import com.google.android.overtheair.v1.GetGroupMemberRequest;
import com.google.android.overtheair.v1.GetGroupRequest;
import com.google.android.overtheair.v1.GetPackageRequest;
import com.google.android.overtheair.v1.Group;
import com.google.android.overtheair.v1.GroupMember;
import com.google.android.overtheair.v1.ListConfigPackagesRequest;
import com.google.android.overtheair.v1.ListConfigPackagesResponse;
import com.google.android.overtheair.v1.ListConfigsRequest;
import com.google.android.overtheair.v1.ListConfigsResponse;
import com.google.android.overtheair.v1.ListConfigsUsingPackageRequest;
import com.google.android.overtheair.v1.ListConfigsUsingPackageResponse;
import com.google.android.overtheair.v1.ListDeploymentsRequest;
import com.google.android.overtheair.v1.ListDeploymentsResponse;
import com.google.android.overtheair.v1.ListGroupChartsRequest;
import com.google.android.overtheair.v1.ListGroupChartsResponse;
import com.google.android.overtheair.v1.ListGroupConfigsRequest;
import com.google.android.overtheair.v1.ListGroupConfigsResponse;
import com.google.android.overtheair.v1.ListGroupMembersRequest;
import com.google.android.overtheair.v1.ListGroupMembersResponse;
import com.google.android.overtheair.v1.ListGroupsRequest;
import com.google.android.overtheair.v1.ListGroupsResponse;
import com.google.android.overtheair.v1.ListPackagesRequest;
import com.google.android.overtheair.v1.ListPackagesResponse;
import com.google.android.overtheair.v1.OverTheAirServiceGrpc.OverTheAirServiceImplBase;
import com.google.android.overtheair.v1.UpdateConfigPackagesRequest;
import com.google.android.overtheair.v1.UpdateConfigPackagesResponse;
import com.google.android.overtheair.v1.UpdateConfigRequest;
import com.google.android.overtheair.v1.UpdateDeploymentRequest;
import com.google.android.overtheair.v1.UpdateGroupConfigsRequest;
import com.google.android.overtheair.v1.UpdateGroupConfigsResponse;
import com.google.android.overtheair.v1.UpdateGroupRequest;
import com.google.android.overtheair.v1.UpdatePackageRequest;
import com.google.api.core.BetaApi;
import com.google.protobuf.AbstractMessage;
import io.grpc.stub.StreamObserver;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;
import java.util.Queue;

@javax.annotation.Generated("by GAPIC")
@BetaApi
public class MockOverTheAirServiceImpl extends OverTheAirServiceImplBase {
  private List<AbstractMessage> requests;
  private Queue<Object> responses;

  public MockOverTheAirServiceImpl() {
    requests = new ArrayList<>();
    responses = new LinkedList<>();
  }

  public List<AbstractMessage> getRequests() {
    return requests;
  }

  public void addResponse(AbstractMessage response) {
    responses.add(response);
  }

  public void setResponses(List<AbstractMessage> responses) {
    this.responses = new LinkedList<Object>(responses);
  }

  public void addException(Exception exception) {
    responses.add(exception);
  }

  public void reset() {
    requests = new ArrayList<>();
    responses = new LinkedList<>();
  }

  @Override
  public void getDeployment(
      GetDeploymentRequest request, StreamObserver<Deployment> responseObserver) {
    Object response = responses.remove();
    if (response instanceof Deployment) {
      requests.add(request);
      responseObserver.onNext((Deployment) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void listDeployments(
      ListDeploymentsRequest request, StreamObserver<ListDeploymentsResponse> responseObserver) {
    Object response = responses.remove();
    if (response instanceof ListDeploymentsResponse) {
      requests.add(request);
      responseObserver.onNext((ListDeploymentsResponse) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void updateDeployment(
      UpdateDeploymentRequest request, StreamObserver<Deployment> responseObserver) {
    Object response = responses.remove();
    if (response instanceof Deployment) {
      requests.add(request);
      responseObserver.onNext((Deployment) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void getPackage(
      GetPackageRequest request,
      StreamObserver<com.google.android.overtheair.v1.Package> responseObserver) {
    Object response = responses.remove();
    if (response instanceof com.google.android.overtheair.v1.Package) {
      requests.add(request);
      responseObserver.onNext((com.google.android.overtheair.v1.Package) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void listPackages(
      ListPackagesRequest request, StreamObserver<ListPackagesResponse> responseObserver) {
    Object response = responses.remove();
    if (response instanceof ListPackagesResponse) {
      requests.add(request);
      responseObserver.onNext((ListPackagesResponse) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void deletePackage(
      DeletePackageRequest request, StreamObserver<DeletePackageResponse> responseObserver) {
    Object response = responses.remove();
    if (response instanceof DeletePackageResponse) {
      requests.add(request);
      responseObserver.onNext((DeletePackageResponse) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void updatePackage(
      UpdatePackageRequest request,
      StreamObserver<com.google.android.overtheair.v1.Package> responseObserver) {
    Object response = responses.remove();
    if (response instanceof com.google.android.overtheair.v1.Package) {
      requests.add(request);
      responseObserver.onNext((com.google.android.overtheair.v1.Package) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void createConfig(CreateConfigRequest request, StreamObserver<Config> responseObserver) {
    Object response = responses.remove();
    if (response instanceof Config) {
      requests.add(request);
      responseObserver.onNext((Config) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void getConfig(GetConfigRequest request, StreamObserver<Config> responseObserver) {
    Object response = responses.remove();
    if (response instanceof Config) {
      requests.add(request);
      responseObserver.onNext((Config) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void listConfigs(
      ListConfigsRequest request, StreamObserver<ListConfigsResponse> responseObserver) {
    Object response = responses.remove();
    if (response instanceof ListConfigsResponse) {
      requests.add(request);
      responseObserver.onNext((ListConfigsResponse) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void deleteConfig(
      DeleteConfigRequest request, StreamObserver<DeleteConfigResponse> responseObserver) {
    Object response = responses.remove();
    if (response instanceof DeleteConfigResponse) {
      requests.add(request);
      responseObserver.onNext((DeleteConfigResponse) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void updateConfig(UpdateConfigRequest request, StreamObserver<Config> responseObserver) {
    Object response = responses.remove();
    if (response instanceof Config) {
      requests.add(request);
      responseObserver.onNext((Config) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void createGroup(CreateGroupRequest request, StreamObserver<Group> responseObserver) {
    Object response = responses.remove();
    if (response instanceof Group) {
      requests.add(request);
      responseObserver.onNext((Group) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void getGroup(GetGroupRequest request, StreamObserver<Group> responseObserver) {
    Object response = responses.remove();
    if (response instanceof Group) {
      requests.add(request);
      responseObserver.onNext((Group) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void listGroups(
      ListGroupsRequest request, StreamObserver<ListGroupsResponse> responseObserver) {
    Object response = responses.remove();
    if (response instanceof ListGroupsResponse) {
      requests.add(request);
      responseObserver.onNext((ListGroupsResponse) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void deleteGroup(
      DeleteGroupRequest request, StreamObserver<DeleteGroupResponse> responseObserver) {
    Object response = responses.remove();
    if (response instanceof DeleteGroupResponse) {
      requests.add(request);
      responseObserver.onNext((DeleteGroupResponse) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void updateGroup(UpdateGroupRequest request, StreamObserver<Group> responseObserver) {
    Object response = responses.remove();
    if (response instanceof Group) {
      requests.add(request);
      responseObserver.onNext((Group) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void disableGroups(
      DisableGroupsRequest request, StreamObserver<DisableGroupsResponse> responseObserver) {
    Object response = responses.remove();
    if (response instanceof DisableGroupsResponse) {
      requests.add(request);
      responseObserver.onNext((DisableGroupsResponse) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void enableGroups(
      EnableGroupsRequest request, StreamObserver<EnableGroupsResponse> responseObserver) {
    Object response = responses.remove();
    if (response instanceof EnableGroupsResponse) {
      requests.add(request);
      responseObserver.onNext((EnableGroupsResponse) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void createGroupMember(
      CreateGroupMemberRequest request, StreamObserver<GroupMember> responseObserver) {
    Object response = responses.remove();
    if (response instanceof GroupMember) {
      requests.add(request);
      responseObserver.onNext((GroupMember) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void createGroupMembers(
      CreateGroupMembersRequest request,
      StreamObserver<CreateGroupMembersResponse> responseObserver) {
    Object response = responses.remove();
    if (response instanceof CreateGroupMembersResponse) {
      requests.add(request);
      responseObserver.onNext((CreateGroupMembersResponse) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void getGroupMember(
      GetGroupMemberRequest request, StreamObserver<GroupMember> responseObserver) {
    Object response = responses.remove();
    if (response instanceof GroupMember) {
      requests.add(request);
      responseObserver.onNext((GroupMember) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void listGroupMembers(
      ListGroupMembersRequest request, StreamObserver<ListGroupMembersResponse> responseObserver) {
    Object response = responses.remove();
    if (response instanceof ListGroupMembersResponse) {
      requests.add(request);
      responseObserver.onNext((ListGroupMembersResponse) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void deleteGroupMember(
      DeleteGroupMemberRequest request,
      StreamObserver<DeleteGroupMemberResponse> responseObserver) {
    Object response = responses.remove();
    if (response instanceof DeleteGroupMemberResponse) {
      requests.add(request);
      responseObserver.onNext((DeleteGroupMemberResponse) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void deleteGroupMembers(
      DeleteGroupMembersRequest request,
      StreamObserver<DeleteGroupMembersResponse> responseObserver) {
    Object response = responses.remove();
    if (response instanceof DeleteGroupMembersResponse) {
      requests.add(request);
      responseObserver.onNext((DeleteGroupMembersResponse) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void getGroupChart(GetGroupChartRequest request, StreamObserver<Chart> responseObserver) {
    Object response = responses.remove();
    if (response instanceof Chart) {
      requests.add(request);
      responseObserver.onNext((Chart) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void listGroupCharts(
      ListGroupChartsRequest request, StreamObserver<ListGroupChartsResponse> responseObserver) {
    Object response = responses.remove();
    if (response instanceof ListGroupChartsResponse) {
      requests.add(request);
      responseObserver.onNext((ListGroupChartsResponse) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void listGroupConfigs(
      ListGroupConfigsRequest request, StreamObserver<ListGroupConfigsResponse> responseObserver) {
    Object response = responses.remove();
    if (response instanceof ListGroupConfigsResponse) {
      requests.add(request);
      responseObserver.onNext((ListGroupConfigsResponse) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void updateGroupConfigs(
      UpdateGroupConfigsRequest request,
      StreamObserver<UpdateGroupConfigsResponse> responseObserver) {
    Object response = responses.remove();
    if (response instanceof UpdateGroupConfigsResponse) {
      requests.add(request);
      responseObserver.onNext((UpdateGroupConfigsResponse) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void disableAllEnabledGroupsOfConfig(
      DisableAllEnabledGroupsOfConfigRequest request,
      StreamObserver<DisableAllEnabledGroupsOfConfigResponse> responseObserver) {
    Object response = responses.remove();
    if (response instanceof DisableAllEnabledGroupsOfConfigResponse) {
      requests.add(request);
      responseObserver.onNext((DisableAllEnabledGroupsOfConfigResponse) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void listConfigPackages(
      ListConfigPackagesRequest request,
      StreamObserver<ListConfigPackagesResponse> responseObserver) {
    Object response = responses.remove();
    if (response instanceof ListConfigPackagesResponse) {
      requests.add(request);
      responseObserver.onNext((ListConfigPackagesResponse) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void updateConfigPackages(
      UpdateConfigPackagesRequest request,
      StreamObserver<UpdateConfigPackagesResponse> responseObserver) {
    Object response = responses.remove();
    if (response instanceof UpdateConfigPackagesResponse) {
      requests.add(request);
      responseObserver.onNext((UpdateConfigPackagesResponse) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }

  @Override
  public void listConfigsUsingPackage(
      ListConfigsUsingPackageRequest request,
      StreamObserver<ListConfigsUsingPackageResponse> responseObserver) {
    Object response = responses.remove();
    if (response instanceof ListConfigsUsingPackageResponse) {
      requests.add(request);
      responseObserver.onNext((ListConfigsUsingPackageResponse) response);
      responseObserver.onCompleted();
    } else if (response instanceof Exception) {
      responseObserver.onError((Exception) response);
    } else {
      responseObserver.onError(new IllegalArgumentException("Unrecognized response type"));
    }
  }
}
